@@ -19,7 +19,7 @@ class FasterWhisperAdapter:
         self, audio_path: Path, initial_prompt: str
     ) -> typing.Iterable[interfaces.Segment]:
         segments, _ = self.whisper_model.transcribe(
-            audio=audio_path, initial_prompt=initial_prompt
+            audio=audio_path, initial_prompt=initial_prompt, vad_filter=True
         )
         return (
             interfaces.Segment(start=segment.start, end=segment.end, text=segment.text)
